@@ -35,6 +35,9 @@ def generate(obj, file: str, template: str, artwork: str = None, season: str = N
     - Season: -s is set and -e is not.
     - Episode: -e is set. -s can be set or not though it's recommended.
     """
+    if not os.path.exists(file):
+        raise click.ClickException("The provided file or folder path does not exist.")
+
     if season is not None and season.isdigit():
         season = int(season)
 
@@ -43,20 +46,24 @@ def generate(obj, file: str, template: str, artwork: str = None, season: str = N
     config = obj["config_path"]
     if config.exists():
         with config.open() as f:
-            nfo.set_config(
-                str(Path(file).resolve()),
-                season,
-                episode,
-                **dict(
-                    imdb=imdb,
-                    tmdb=tmdb,
-                    tvdb=tvdb,
-                    source=source,
-                    note=note,
-                    preview=preview,
-                    **yaml.load(f, Loader=yaml.FullLoader)
-                )
-            )
+            config = yaml.load(f, Loader=yaml.FullLoader)
+    else:
+        config = {}
+
+    nfo.set_config(
+        str(Path(file).resolve()),
+        season,
+        episode,
+        **dict(
+            imdb=imdb,
+            tmdb=tmdb,
+            tvdb=tvdb,
+            source=source,
+            note=note,
+            preview=preview,
+            **config
+        )
+    )
 
     template_vars = {
         "videos_pretty": nfo.get_video_print(nfo.videos),
